@@ -22,16 +22,16 @@ from hsml.decorators import connected, not_connected
 from hsml import client
 from hsml.core import model_api, model_registry_api, model_serving_api
 
-AWS_DEFAULT_REGION = "default"
+CONNECTION_SAAS_HOSTNAME = "c.app.hopsworks.ai"
+
 HOPSWORKS_PORT_DEFAULT = 443
-SECRETS_STORE_DEFAULT = "parameterstore"
 HOSTNAME_VERIFICATION_DEFAULT = True
 
 
 class Connection:
-    """A Model registry connection object.
+    """A Hopsworks Model Management connection object.
 
-    The connection is project specific, so you can access the project's own model registry.
+    The connection is project specific, so you can access the project's own Model Registry and Model Serving.
 
     This class provides convenience classmethods accessible from the `hsml`-module:
 
@@ -45,10 +45,9 @@ class Connection:
         ```
 
     !!! hint "Save API Key as File"
-        To get started quickly, without saving the Hopsworks API in a secret storage,
-        you can simply create a file with the previously created Hopsworks API Key and
-        place it on the environment from which you wish to connect to the Hopsworks
-        Model Registry.
+        To get started quickly, you can simply create a file with the previously
+         created Hopsworks API Key and place it on the environment from which you
+         wish to connect to Hopsworks.
 
         You can then connect by simply passing the path to the key file when
         instantiating a connection:
@@ -56,21 +55,21 @@ class Connection:
         ```python hl_lines="6"
             import hsml
             conn = hsml.connection(
-                'my_instance',                      # DNS of your Model Registry instance
+                'my_instance',                      # DNS of your Hopsworks instance
                 443,                                # Port to reach your Hopsworks instance, defaults to 443
-                'my_project',                       # Name of your Hopsworks Model Registry project
+                'my_project',                       # Name of your Hopsworks project
                 api_key_file='modelregistry.key',   # The file containing the API key generated above
                 hostname_verification=True)         # Disable for self-signed certificates
             )
             mr = conn.get_model_registry()          # Get the project's default model registry
-            ms = conn.get_model_serving()           # Get the project's default model serving
+            ms = conn.get_model_serving()           # Uses the previous model registry
         ```
 
-    Clients in external clusters need to connect to the Hopsworks Model Registry using an
+    Clients in external clusters need to connect to the Hopsworks Model Registry and Model Serving using an
     API key. The API key is generated inside the Hopsworks platform, and requires at
-    least the "project", "modelregistry", "dataset.create", "dataset.view", "dataset.delete", "serving" scopes
+    least the "project", "modelregistry", "dataset.create", "dataset.view", "dataset.delete", "serving" and "kafka" scopes
     to be able to access a model registry and its model serving.
-    For more information, see the [integration guides](../setup.md).
+    For more information, see the [integration guides](../../integrations/overview.md).
 
     # Arguments
         host: The hostname of the Hopsworks instance, defaults to `None`.
@@ -79,19 +78,13 @@ class Connection:
         project: The name of the project to connect to. When running on Hopsworks, this
             defaults to the project from where the client is run from.
             Defaults to `None`.
-        region_name: The name of the AWS region in which the required secrets are
-            stored, defaults to `"default"`.
-        secrets_store: The secrets storage to be used, either `"secretsmanager"`,
-            `"parameterstore"` or `"local"`, defaults to `"parameterstore"`.
         hostname_verification: Whether or not to verify Hopsworks certificate, defaults
             to `True`.
         trust_store_path: Path on the file system containing the Hopsworks certificates,
             defaults to `None`.
-        api_key_file: Path to a file containing the API Key, if provided,
-            `secrets_store` will be ignored, defaults to `None`.
-        api_key_value: API Key as string, if provided, `secrets_store` will be ignored`,
-            however, this should be used with care, especially if the used notebook or
-            job script is accessible by multiple parties. Defaults to `None`.
+        api_key_file: Path to a file containing the API Key.
+        api_key_value: API Key as string, if provided, however, this should be used with care,
+        especially if the used notebook or job script is accessible by multiple parties. Defaults to `None`.
 
     # Returns
         `Connection`. Connection handle to perform operations on a Hopsworks project.
@@ -102,8 +95,6 @@ class Connection:
         host: str = None,
         port: int = HOPSWORKS_PORT_DEFAULT,
         project: str = None,
-        region_name: str = AWS_DEFAULT_REGION,
-        secrets_store: str = SECRETS_STORE_DEFAULT,
         hostname_verification: bool = HOSTNAME_VERIFICATION_DEFAULT,
         trust_store_path: str = None,
         api_key_file: str = None,
@@ -112,8 +103,6 @@ class Connection:
         self._host = host
         self._port = port
         self._project = project
-        self._region_name = region_name
-        self._secrets_store = secrets_store
         self._hostname_verification = hostname_verification
         self._trust_store_path = trust_store_path
         self._api_key_file = api_key_file
@@ -127,9 +116,9 @@ class Connection:
 
     @connected
     def get_model_registry(self, project: str = None):
-        """Get a reference to a model registry to perform operations on.
-        Defaulting to the project's default model registry. Shared model registries can be
-        retrieved by passing the `project` argument.
+        """Get a reference to a model registry to perform operations on, defaulting to the project's default model registry.
+        Shared model registries can be retrieved by passing the `project` argument.
+
         # Arguments
             project: The name of the project that owns the shared model registry,
             the model registry must be shared with the project the connection was established for, defaults to `None`.
@@ -140,8 +129,8 @@ class Connection:
 
     @connected
     def get_model_serving(self):
-        """Get a reference to model serving to perform operations on. Model serving operates on top of a model registry.
-        Connecting to the project's default model registry.
+        """Get a reference to model serving to perform operations on. Model serving operates on top of a model registry, defaulting to the project's default model registry.
+
         # Returns
             `ModelServing`. A model serving handle object to perform operations on.
         """
@@ -154,9 +143,8 @@ class Connection:
         Creating a `Connection` object implicitly calls this method for you to
         instantiate the connection. However, it is possible to close the connection
         gracefully with the `close()` method, in order to clean up materialized
-        certificates. This might be desired when working on external environments such
-        as AWS SageMaker. Subsequently you can call `connect()` again to reopen the
-        connection.
+        certificates. This might be desired when working on external environments.
+        Subsequently you can call `connect()` again to reopen the connection.
 
         !!! example
             ```python
@@ -175,8 +163,6 @@ class Connection:
                     self._host,
                     self._port,
                     self._project,
-                    self._region_name,
-                    self._secrets_store,
                     self._hostname_verification,
                     self._trust_store_path,
                     self._api_key_file,
@@ -186,6 +172,7 @@ class Connection:
                 client.init("internal")
 
             self._model_api = model_api.ModelApi()
+            self._model_serving_api.load_default_configuration()  # istio client, default resources,...
         except (TypeError, ConnectionError):
             self._connected = False
             raise
@@ -195,7 +182,7 @@ class Connection:
         """Close a connection gracefully.
 
         This will clean up any materialized certificates on the local file system of
-        external environments such as AWS SageMaker.
+        external environments.
 
         Usage is recommended but optional.
         """
@@ -210,8 +197,6 @@ class Connection:
         host: str = None,
         port: int = HOPSWORKS_PORT_DEFAULT,
         project: str = None,
-        region_name: str = AWS_DEFAULT_REGION,
-        secrets_store: str = SECRETS_STORE_DEFAULT,
         hostname_verification: bool = HOSTNAME_VERIFICATION_DEFAULT,
         trust_store_path: str = None,
         api_key_file: str = None,
@@ -222,8 +207,6 @@ class Connection:
             host,
             port,
             project,
-            region_name,
-            secrets_store,
             hostname_verification,
             trust_store_path,
             api_key_file,
@@ -257,24 +240,6 @@ class Connection:
     def project(self, project):
         self._project = project
 
-    @property
-    def region_name(self):
-        return self._region_name
-
-    @region_name.setter
-    @not_connected
-    def region_name(self, region_name):
-        self._region_name = region_name
-
-    @property
-    def secrets_store(self):
-        return self._secrets_store
-
-    @secrets_store.setter
-    @not_connected
-    def secrets_store(self, secrets_store):
-        self._secrets_store = secrets_store
-
     @property
     def hostname_verification(self):
         return self._hostname_verification
