@@ -18,12 +18,15 @@ import json
 import humps
 from typing import Union, Optional
 
-from hsml import util
+from hsml import client, util
 
+from hsml.constants import ARTIFACT_VERSION
 from hsml.engine import model_engine
 from hsml.predictor import Predictor
-from hsml.predictor_config import PredictorConfig
-from hsml.transformer_config import TransformerConfig
+from hsml.resources import PredictorResources
+from hsml.inference_logger import InferenceLogger
+from hsml.inference_batcher import InferenceBatcher
+from hsml.transformer import Transformer
 
 
 class Model:
@@ -50,7 +53,6 @@ class Model:
         model_registry_id=None,
         tags=None,
     ):
-
         self._id = id
         self._name = name
         self._version = version
@@ -106,26 +108,50 @@ class Model:
     def deploy(
         self,
         name: Optional[str] = None,
-        artifact_version: Optional[str] = "CREATE",
-        predictor_config: Optional[Union[PredictorConfig, dict]] = None,
-        transformer_config: Optional[Union[TransformerConfig, dict]] = None,
+        artifact_version: Optional[str] = ARTIFACT_VERSION.CREATE,
+        model_server: Optional[str] = None,
+        serving_tool: Optional[str] = None,
+        script_file: Optional[str] = None,
+        resources: Optional[Union[PredictorResources, dict]] = None,
+        inference_logger: Optional[Union[InferenceLogger, dict]] = None,
+        inference_batcher: Optional[Union[InferenceBatcher, dict]] = None,
+        transformer: Optional[Union[Transformer, dict]] = None,
     ):
-        """Deploy the model"""
+        """Deploy the model.
+
+        # Arguments
+            name: Name of the deployment.
+            artifact_version: Version number of the model artifact to deploy, `CREATE` to create a new model artifact
+            or `MODEL-ONLY` to reuse the shared artifact containing only the model files.
+            model_server: Model server ran by the predictor.
+            serving_tool: Serving tool used to deploy the model server.
+            script_file: Path to a custom predictor script implementing the Predict class.
+            resources: Resources to be allocated for the predictor.
+            inference_logger: Inference logger configuration.
+            inference_batcher: Inference batcher configuration.
+            transformer: Transformer to be deployed together with the predictor.
+
+        # Returns
+            `Deployment`. The deployment metadata object.
+        """
 
         if name is None:
             name = self._name
-        if predictor_config is None:
-            predictor_config = PredictorConfig.for_model(self)
 
-        return Predictor(
-            name,
-            self._name,
-            self.model_path,
-            self._version,
-            artifact_version,
-            predictor_config,
-            transformer_config=transformer_config,
-        ).deploy()
+        predictor = Predictor.for_model(
+            self,
+            name=name,
+            artifact_version=artifact_version,
+            model_server=model_server,
+            serving_tool=serving_tool,
+            script_file=script_file,
+            resources=resources,
+            inference_logger=inference_logger,
+            inference_batcher=inference_batcher,
+            transformer=transformer,
+        )
+
+        return predictor.deploy()
 
     @classmethod
     def from_response_json(cls, json_dict):
@@ -385,3 +411,17 @@ class Model:
             `RestAPIError` in case the backend fails to retrieve the tags.
         """
         return self._model_engine.get_tags(self)
+
+    def __repr__(self):
+        return f"Model(name: {self._name!r}, version: {self._version!r})"
+
+    def get_url(self):
+        path = (
+            "/p/"
+            + str(client.get_instance()._project_id)
+            + "/models/"
+            + str(self.name)
+            + "/"
+            + str(self.version)
+        )
+        return util.get_hostname_replaced_url(path)
